==> isCOBOL_2025_R1_1145_9_20250707_40290_Linux.64.x86_64.tar.gz: sample/as/custom-login/README.md <==

##### isCOBOL release 2025 R1 build#1145.9-20250707-40290 ######
##### Copyright (c) 2005 - 2025 Veryant. ######

----------
**This sample shows the CUSTOM LOGIN feature.**

**The A$CUSTOM_LOGIN program class will be automatically called when a Client is**
**started and iscobol.as.authentication property is set to a value greater than 0**
**If not found, the standard login panel will be shown.**

**This document assumes the $ISCOBOL environment variable exists and points**
**to the isCOBOL SDK installation folder.**

**When talking about a "command prompt window" it means an isCOBOL Shell**
**on the Windows OS and a standard shell on Linux/Unix**

----------
 - 1 On the server computer, create a temporary folder with an iscobol.properties 
    file including this property

        iscobol.as.authentication=1 or
        iscobol.as.authentication=2

 - 2 From that temporary folder on the server computer start an isCOBOL Application 
    Server with this command:

        iscserver -hostname <ip-address> -port <port-number>

 **NOTE:**

        If you have already started an instance of the Application Server,
        you can start a new instance of it on a different port**

 - 3 On the client computer, Using a command prompt window go to the 
    "$ISCOBOL/sample/as/custom-login" folder.

 - 4 Compile the A$CUSTOM-LOGIN.cbl program

        iscc *.cbl

 - 5 Start a thin-client panel session

        iscclient -hostname <ip-address> -port <port-number> -panel

 **NOTE:**

    the custom-login dialog defined in A$CUSTOM-LOGIN.cbl program
    is used instead of the standard one

==> isCOBOL_2025_R2_1158_10_20251128_41083_Linux.64.x86_64.tar.gz: sample/as/custom-login/README.md <==

##### isCOBOL release 2025 R2 build#1158.10-20251128-41083 ######
##### Copyright (c) 2005 - 2025 Veryant. ######

----------
**This sample shows the CUSTOM LOGIN feature.**

**The A$CUSTOM_LOGIN program class will be automatically called when a Client is**
**started and iscobol.as.authentication property is set to a value greater than 0**
**If not found, the standard login panel will be shown.**

**This document assumes the $ISCOBOL environment variable exists and points**
**to the isCOBOL SDK installation folder.**

**When talking about a "command prompt window" it means an isCOBOL Shell**
**on the Windows OS and a standard shell on Linux/Unix**

----------
 - 1 On the server computer, create a temporary folder with an iscobol.properties 
    file including this property

        iscobol.as.authentication=1 or
        iscobol.as.authentication=2

 - 2 From that temporary folder on the server computer start an isCOBOL Application 
    Server with this command:

        iscserver -hostname <ip-address> -port <port-number>

 **NOTE:**

        If you have already started an instance of the Application Server,
        you can start a new instance of it on a different port

 - 3 On the client computer, Using a command prompt window go to the 
    "$ISCOBOL/sample/as/custom-login" folder.

 - 4 Compile the A$CUSTOM-LOGIN.cbl program

        iscc *.cbl

 - 5 Start a thin-client panel session

        iscclient -hostname <ip-address> -port <port-number> -panel

 **NOTE:**

    the custom-login dialog defined in A$CUSTOM-LOGIN.cbl program
    is used instead of the standard one
